@@ -5,8 +5,8 @@ use crate::CpuExtensions;
 
 use super::{Coefficients, Convolution};
 
-// #[cfg(target_arch = "x86_64")]
-// mod avx2;
+#[cfg(target_arch = "x86_64")]
+mod avx2;
 mod native;
 // #[cfg(target_arch = "x86_64")]
 // mod sse4;
@@ -20,8 +20,8 @@ impl Convolution for U8x2 {
         cpu_extensions: CpuExtensions,
     ) {
         match cpu_extensions {
-            // #[cfg(target_arch = "x86_64")]
-            // CpuExtensions::Avx2 => avx2::horiz_convolution(src_image, dst_image, offset, coeffs),
+            #[cfg(target_arch = "x86_64")]
+            CpuExtensions::Avx2 => avx2::horiz_convolution(src_image, dst_image, offset, coeffs),
             // #[cfg(target_arch = "x86_64")]
             // CpuExtensions::Sse4_1 => unsafe {
             //     sse4::horiz_convolution(src_image, dst_image, offset, coeffs)
