@@ -13,12 +13,3 @@ pub(crate) unsafe fn horiz_convolution(
 ) {
     native::horiz_convolution(src_image, dst_image, offset, coeffs);
 }
-
-#[target_feature(enable = "sse4.1")]
-pub(crate) unsafe fn vert_convolution(
-    src_image: TypedImageView<U8x3>,
-    dst_image: TypedImageViewMut<U8x3>,
-    coeffs: Coefficients,
-) {
-    native::vert_convolution(src_image, dst_image, coeffs);
-}
